@@ -31,6 +31,7 @@ import org.irisa.genouest.logol.utils.LogolUtils;
  * 28/04/11 @FIX 1794
  * 26/05/11 @FIX 1800
  * 20/06/11 @FIX 1806
+ * 04/10/13 Fix case when distance but no cost
  */
 public class Variable extends AbstractVariable{
 
@@ -843,12 +844,12 @@ public class Variable extends AbstractVariable{
 				mindistance = tmp_mindistance;
 				}
 				
-				prologSentence+=",getsuffixmatch_pos('"+Treatment.suffixSearchPath+"','"+filename+".fsa',"+motif+","+distance+","+Treatment.sequenceLength+" ,"+Constants.LOGOLVARBEFORE+varID+",0,"+Constants.LOGOLVARINDEL+varID+","+Constants.LOGOLVARAFTER+varID+","+suffixMin+","+suffixMax+","+Constants.LOGOLVARSPACER+varID+")";
+				prologSentence+=",getsuffixmatch_pos('"+Treatment.suffixSearchPath+"','"+filename+".fsa',"+motif+","+distance+","+Treatment.sequenceLength+","+Constants.LOGOLVARBEFORE+varID+",0,"+Constants.LOGOLVARINDEL+varID+",_,"+suffixMin+","+suffixMax+","+Constants.LOGOLVARSPACER+varID+")";
 				//TODO check it is distance only
 				String matchpos = LogolUtils.getTemporaryVariable();
 				prologSentence+=","+matchpos+" is "+Constants.LOGOLVARBEFORE+varID+" + "+Constants.LOGOLVARSPACER+varID;
 				//isexactwithdistinctgapanderror_pos(InputPos,[E1 | E2], MaxError, MaxDistance, Errors, DistanceErrors, OutPos)
-				prologSentence+=",isexactwithdistinctgapanderror_pos("+matchpos+","+motif+", 0, "+distance+", "+Constants.LOGOLVARERRORS+varID+", "+Constants.LOGOLVARINDEL+varID+",_)";
+				prologSentence+=",isexactwithdistinctgapanderror_pos("+matchpos+","+motif+",0, "+distance+", "+Constants.LOGOLVARERRORS+varID+","+Constants.LOGOLVARINDEL+varID+","+Constants.LOGOLVARAFTER+varID+")";
 				prologSentence += ","+Constants.LOGOLVARERRORS+varID+"=0";
 				prologSentence+=","+Constants.LOGOLVARERRORS+varID+">="+mindistance;
 			}
